@@ -1131,7 +1131,7 @@ class RedisClient(AbstractClient):
 
 
     def DescribeMaintenanceWindow(self, request):
-        """查询实例维护时间窗，在实例需要进行版本升级或者架构升级的时候，会在维护时间窗时间内进行切换
+        """本接口（DescribeMaintenanceWindow）用于查询实例维护时间窗。在实例需要进行版本升级或者架构升级的时候，会在维护时间窗时间内进行切换
 
         :param request: Request instance for DescribeMaintenanceWindow.
         :type request: :class:`tencentcloud.redis.v20180412.models.DescribeMaintenanceWindowRequest`
@@ -1591,7 +1591,7 @@ class RedisClient(AbstractClient):
 
 
     def InquiryPriceRenewInstance(self, request):
-        """查询实例续费价格（包年包月）
+        """本接口（InquiryPriceRenewInstance）用于查询包年包月计费实例的续费价格。
 
         :param request: Request instance for InquiryPriceRenewInstance.
         :type request: :class:`tencentcloud.redis.v20180412.models.InquiryPriceRenewInstanceRequest`
